@@ -1679,6 +1679,8 @@ class IsoDistributive(Distributive):
             self._makeDirectory(directory)
             tf = typeFile(magic=MAGIC_COMPRESS | MAGIC_SYMLINK | MAGIC_CONTINUE)
             ftype = tf.getMType(file)
+            if ftype is None:
+                raise DistributiveError(_("Failed to get Mtype of the iso file"))
             if "block special" in ftype:
                 mopts = "-o ro"
             else:
